MethodChannelUaePass class

An implementation of UaePassPlatform that uses method channels.

Inheritance

Constructors

MethodChannelUaePass()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccessToken(String code) → Future<String>
override
getProfile(String accessToken) → Future
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUp({required String clientId, required String clientSecret, required bool isProduction, required String urlScheme, required String state, required String redirectUri, required String scope, required String language}) → Future<void>
override
signIn() → Future<String>
override
signOut() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited